function room= draw_room(XY, a_XY, b_XY)
% room= draw_room(XY, a_XY, b_XY)
%   function for drawing a room from dimensions of room
%   and positions of listener and sound source
%    INPUT ARGUMENTS
%     XY= [a b]     simulating room dimensions
%     a_XY= [x y]     listener's position in the room
%     b_XY= [x y]     sound source's position in the room
% -------------------------------------------------------

if nargin == 0
    XY= [6 10];
    a_XY= [1 6];
    b_XY= [2 7];
end

height= 160;
width= 120;

% [236 233 216]*
room= ones(height, width, 3);
room(:,:,1)= (0.925*room(:,:,1));
room(:,:,2)= (0.914*room(:,:,2));
room(:,:,3)= (0.847*room(:,:,3));

point= 3;

if ( (width-10)/XY(1) < (height-10)/XY(2) )
    n= (width-10)/XY(1); 
else
    n= (height-10)/XY(2);
end

% finding extreme positions
x1= uint8( (width- round(n*XY(1)) )/2);
x2=  x1+ round(n*XY(1));
y1= uint8((height- round(n*XY(2)) )/2);
y2=  y1+ round(n*XY(2));

% walls drawing
room(y1:y1+1,x1:x2,:)= 0;
room(y2-1:y2,x1:x2,:)= 0;
room(y1:y2,x1:x1+1,:)= 0;
room(y1:y2,x2-1:x2,:)= 0;
% floor drawing
room(y1+2:y2-2,x1+2:x2-2,:)= 1;

p= (point-1)/2;

if (length(a_XY)==2 &&(not (isnan(a_XY(1)))&& not( isnan(a_XY(2)))))
    % listener position drawing
    x= uint8( x1 + round(n*a_XY(1)));
    y= uint8( y2 - round(n*a_XY(2)));
    room(y-p:y+p,x-p:x+p,1:2)= zeros(point, point, 2);
end

if (length(b_XY)==2 &&(not (isnan(b_XY(1)))&& not( isnan(b_XY(2)))))
    % sound source positon drawing
    x= uint8( x1 + round(n*b_XY(1)));
    y= uint8( y2 - round(n*b_XY(2)));
    room(y-p:y+p,x-p:x+p,2:3)=  zeros(point, point, 2);
end